==> escapework-manager-0.3.0-965592.tar: readme.md <==
## escape.manager

CMS da Escape para ser instalado com o Laravel 4. Instalação disponível via Composer.

### composer.json

Edite o seu arquivo `composer.json` adicionando o repositório do escape.manager.

```javascript
"require": {
    "escapework/manager": "0.3.*" 
}, 

"repositories": [
    {
        "type": "git",
        "url": "git@github.com:escapecriativacao/escape.manager.git"
    }
]
```

Depois, rode o comando `composer update`.

### Publicando o pacote e suas configurações

Edite o arquivo `app/config/app.php`, adicionando a seguinte linha no array de providers: 

```php
    'EscapeWork\Manager\ManagerServiceProvider', 
    'EscapeWork\Msg\Laravel\MsgServiceProvider', 
```

Também adicione os aliases para o [EscapeWork\Msg](https://github.com/EscapeWork/Msg) e o [EscapeWork\LaravelHelpers](https://github.com/EscapeWork/LaravelHelpers);

```php
    'Eloquent'        => 'EscapeWork\LaravelHelpers\Eloquent',
    'Msg'             => 'EscapeWork\Msg\Msg', 
    'Check'           => 'EscapeWork\Manager\Check', 
```

Depois de baixar o pacote, execute os seguintes comandos: 

- `$ php artisan config:publish escapework/manager`
- `$ php artisan asset:publish escapework/manager`
- `$ php artisan migrate --package="escapework/manager"`

Agora, precisamos executar os seeds, e criar o primeiro usuário. Para isso, abra o arquivo `app/database/seeds/DatabaseSeeder.php`, e adicione a seguinte linha: 

```php
# from package escapework/manager
$this->call('EscapeWork\Manager\Seed\ManagerTableSeeder');
```

Depois, executa o comando de seed.

`$ php artisan db:seed`

Altere o model utilizado pela classe de autenticação, alterando a linha no arquivo `app/config/auth.php`

```php
    'model' => 'EscapeWork\Manager\Model\User',
```

Agora, a URL `seudominio.dev/manager` já está disponível para acesso.

***

### Templates

Para extender o layout master, utilize da seguinte forma: 

```php
@extends('manager::layouts.master')

@section('styles')
    @parent
    <link href="/css" rel="stylesheet" type="text/css" />
@stop

@section('content')
    Contúdo da página
@stop

@section('scripts')
    @parent
    <script src="/js" type="text/javascript"></script>
@stop
```

Para editar o menu, crie um template chamado `menu.blade.php` na raiz do seu projeto. Caso queira utilizar outro nome, altere a configuração `menu`, nas configurações do escape.manager.

```php
<li><a href="{{ route('manager.clientes.index') }}">Clientes</a></li>
<li><a href="{{ route('categorias.index') }}">Categorias</a></li>
```

***

### Permissões de acesso

Para testar as permissões de acesso, utilize o seguinte comando: 

```php
Check::can('categories', 'read'); // (page|action) true or false

@if (Check::can('users', 'create'))
    <a href="#" class="btn">Insert new user</a>
@endif
```

Para exibir ou não exibir no menu, pode-se testar como no exemplo abaixo, verificando se o usuário tem pelo menos 1 permissão de acesso a página.

```php
@if (Check::canAny('users')
    <a href="{{ route('usuarios.index') }}" class="btn">Usuários</a>
@endif
```

Você também pode testar a permissão de acesso diretamente no seu controller.

```php
use EscapeWork\Manager\Controller\ManagerController;

class UserController extends ManagerController
{

    public function __construct()
    {
        # CRUD - default filters
        # create -> methods (create, store)
        # read -> methods (show)
        # update -> methods (edit, update)
        # destroy -> methods (destroy)
        $this->enableDefaultFilters('users');
    
        # custom permissions filters 
        $this->beforeFilter(function()
        {
            Check::canOrFail('users', 'read');
        }, array('only' => array('print')));
    }
}
```

### Templates

Você pode reescrever o template padrão da home. Para isso, basta alterar o array de configurações de templates que fica em `app/config/packages/escapework/manager/config.php`.

```php
    /**
     * Templates que podem ser sobreescritor
     */
    'templates' => array(
        'home' => 'manager::home', 
    ), 
```

### CKEditor

Para utilizar qualquer editor com o CKEditor, apenas adicione o paramêtro `data-editor` na sua textarea.

```html
    <textarea data-editor></textarea>
```

### Unit Testing 

Para autenticar o usuário, o escapework/manager oferece um TestCase para testar seus controllers do Manager. É só extender a classe `EscapeWork\Manager\TestCase`.

```php
class ProductController extends \EscapeWork\Manager\TestCase
{

}
```

Também existe um helper para retornos em casos de paginação. Ele contém todos os métodos que o [Illuminate\Pagination\Paginator](http://laravel.com/docs/pagination).

```php
class ProductController extends \EscapeWork\Manager\TestCase
{
    public function testIndex()
    {
        $this->product->shouldReceive('paginate')->andReturn($this->paginate);
    }
}
}
```

#### Dependências e Componentes

O **escape.manager** utiliza os seguintes componentes: 

- [EscapeWork/Msg](https://github.com/EscapeWork/Msg)
- [EscapeWork/LaravelHelpers](https://github.com/EscapeWork/LaravelHelpers)
- [Twitter Bootstrap](http://twitter.github.io/bootstrap/)
- [jQuery](http://jquery.com/)
- [jQuery UI](http://jqueryui.com/)
- [jQuery Validate](http://jqueryvalidation.org/)

### Projetos utilizando o escapework/manager

* ADVB (0.3)
* [escape.os](http://os.escape.ppg.br) (0.3)
* Rotermund - CineClub Interativo (0.3)

### Módulos para utilizar junto com o escapework/manager

* [escapework/manager-banners](https://bitbucket.org/escapecria/manager-banners) - Controle de banners
* [escapework/manager-subscribers](https://bitbucket.org/escapecria/manager-subscribers) - Controle de contatos de newsletter

==> escapework-manager-0.4.0-9a43a3.tar: readme.md <==
## escape.manager

CMS da Escape para ser instalado com o Laravel 4. Instalação disponível via Composer.

### composer.json

Edite o seu arquivo `composer.json` adicionando o repositório do escape.manager.

```javascript
"require": {
    "escapework/manager": "0.4.*" 
}, 

"repositories": [
    {
        "type": "git",
        "url": "git@github.com:escapecriativacao/escape.manager.git"
    }
]
```

Depois, rode o comando `composer update`.

### Publicando o pacote e suas configurações

Edite o arquivo `app/config/app.php`, adicionando a seguinte linha no array de providers: 

```php
    'EscapeWork\Manager\ManagerServiceProvider', 
    'EscapeWork\Msg\Laravel\MsgServiceProvider', 
```

Também adicione os aliases para o [EscapeWork\Msg](https://github.com/EscapeWork/Msg) e o [EscapeWork\LaravelHelpers](https://github.com/EscapeWork/LaravelHelpers);

```php
    'Eloquent'        => 'EscapeWork\LaravelHelpers\Eloquent',
    'Msg'             => 'EscapeWork\Msg\Msg', 
    'Check'           => 'EscapeWork\Manager\Check', 
```

Depois de baixar o pacote, execute os seguintes comandos: 

- `$ php artisan config:publish escapework/manager`
- `$ php artisan asset:publish escapework/manager`
- `$ php artisan migrate --package="escapework/manager"`

Agora, precisamos executar os seeds, e criar o primeiro usuário. Para isso, abra o arquivo `app/database/seeds/DatabaseSeeder.php`, e adicione a seguinte linha: 

```php
# from package escapework/manager
$this->call('EscapeWork\Manager\Seed\ManagerTableSeeder');
```

Depois, executa o comando de seed.

`$ php artisan db:seed`

Altere o model utilizado pela classe de autenticação, alterando a linha no arquivo `app/config/auth.php`

```php
    'model' => 'EscapeWork\Manager\Model\User',
```

Agora, a URL `seudominio.dev/manager` já está disponível para acesso.

***

### Templates

Para extender o layout master, utilize da seguinte forma: 

```php
@extends('manager::layouts.master')

@section('styles')
    @parent
    <link href="/css" rel="stylesheet" type="text/css" />
@stop

@section('content')
    Contúdo da página
@stop

@section('scripts')
    @parent
    <script src="/js" type="text/javascript"></script>
@stop
```

Para editar o menu, crie um template chamado `menu.blade.php` na raiz do seu projeto. Caso queira utilizar outro nome, altere a configuração `menu`, nas configurações do escape.manager.

```php
<li><a href="{{ route('manager.clientes.index') }}">Clientes</a></li>
<li><a href="{{ route('categorias.index') }}">Categorias</a></li>
```

***

### Permissões de acesso

Para testar as permissões de acesso, utilize o seguinte comando: 

```php
Check::can('categories', 'read'); // (page|action) true or false

@if (Check::can('users', 'create'))
    <a href="#" class="btn">Insert new user</a>
@endif
```

Para exibir ou não exibir no menu, pode-se testar como no exemplo abaixo, verificando se o usuário tem pelo menos 1 permissão de acesso a página.

```php
@if (Check::canAny('users')
    <a href="{{ route('usuarios.index') }}" class="btn">Usuários</a>
@endif
```

Você também pode testar a permissão de acesso diretamente no seu controller.

```php
use EscapeWork\Manager\Controller\ManagerController;

class UserController extends ManagerController
{

    public function __construct()
    {
        # CRUD - default filters
        # create -> methods (create, store)
        # read -> methods (show)
        # update -> methods (edit, update)
        # destroy -> methods (destroy)
        $this->enableDefaultFilters('users');
    
        # custom permissions filters 
        $this->beforeFilter(function()
        {
            Check::canOrFail('users', 'read');
        }, array('only' => array('print')));
    }
}
```

### Templates

Você pode reescrever o template padrão da home. Para isso, basta alterar o array de configurações de templates que fica em `app/config/packages/escapework/manager/config.php`.

```php
    /**
     * Templates que podem ser sobreescritor
     */
    'templates' => array(
        'home' => 'manager::home', 
    ), 
```

### CKEditor

Para utilizar qualquer editor com o CKEditor, apenas adicione o paramêtro `data-editor` na sua textarea.

```html
    <textarea data-editor></textarea>
```

### Unit Testing 

Para autenticar o usuário, o escapework/manager oferece um TestCase para testar seus controllers do Manager. É só extender a classe `EscapeWork\Manager\TestCase`.

```php
class ProductControllerTest extends \EscapeWork\Manager\TestCase
{

}
```

Também existe um helper para retornos em casos de paginação. Ele contém todos os métodos que o [Illuminate\Pagination\Paginator](http://laravel.com/docs/pagination).

```php
class ProductController extends \EscapeWork\Manager\TestCase
{
    public function test_index()
    {
        $this->product->shouldReceive('paginate')->andReturn($this->paginate);
    }
}
}
```

#### Dependências e Componentes

O **escape.manager** utiliza os seguintes componentes: 

- [EscapeWork/Msg](https://github.com/EscapeWork/Msg)
- [EscapeWork/LaravelHelpers](https://github.com/EscapeWork/LaravelHelpers)
- [Twitter Bootstrap](http://twitter.github.io/bootstrap/)
- [jQuery](http://jquery.com/)
- [jQuery UI](http://jqueryui.com/)
- [jQuery Validate](http://jqueryvalidation.org/)

### Projetos utilizando o escapework/manager

* [ADVB](http://www.advb.com.br) (0.4)
* [escape.os](http://os.escape.ppg.br) (0.3)
* Rotermund - CineClub Interativo (0.3)
* [Gabriel Rosa Leilões](http:://gabrielrosaleiloes.com.br) - CineClub Interativo (0.4)

### Módulos para utilizar junto com o escapework/manager

* [escapework/manager-medias](https://bitbucket.org/escapecria/manager-medias) - Controle de mídias
* [escapework/manager-banners](https://bitbucket.org/escapecria/manager-banners) - Controle de banners
* [escapework/manager-subscribers](https://bitbucket.org/escapecria/manager-subscribers) - Controle de contatos de newsletter
